@@ -1,7 +1,7 @@
 from dataclasses import dataclass, field
 from datetime import datetime
 from enum import Enum
-from typing import Dict, List, Optional, Set, Type, Union
+from typing import Optional, Union
 
 from dataclasses_jsonschema import JsonSchemaMixin
 
@@ -87,15 +87,15 @@ class Sphere(Model):
 class Mesh(Model):
 
     data_id: str
-    focus_points: Optional[List[Pose]] = None
+    focus_points: Optional[list[Pose]] = None
 
 
-MeshList = List[Mesh]
+MeshList = list[Mesh]
 
 PrimitiveModels = Union[Box, Sphere, Cylinder]
 Models = Union[Box, Sphere, Cylinder, Mesh]
 
-MODEL_MAPPING: Dict[Model3dType, Union[Type[Box], Type[Sphere], Type[Cylinder], Type[Mesh]]] = {
+MODEL_MAPPING: dict[Model3dType, Union[type[Box], type[Sphere], type[Cylinder], type[Mesh]]] = {
     Box.type(): Box,
     Sphere.type(): Sphere,
     Cylinder.type(): Cylinder,
@@ -151,10 +151,10 @@ class ObjectModel(JsonSchemaMixin):
 @dataclass
 class CollisionModels(JsonSchemaMixin):
 
-    boxes: List[Box] = field(default_factory=list)
-    spheres: List[Sphere] = field(default_factory=list)
-    cylinders: List[Cylinder] = field(default_factory=list)
-    meshes: List[Mesh] = field(default_factory=list)
+    boxes: list[Box] = field(default_factory=list)
+    spheres: list[Sphere] = field(default_factory=list)
+    cylinders: list[Cylinder] = field(default_factory=list)
+    meshes: list[Mesh] = field(default_factory=list)
 
 
 @dataclass
@@ -163,8 +163,8 @@ class ParameterMeta(JsonSchemaMixin):
     name: str
     type: str
     dynamic_value: bool = False  # client should ask for allowed values using RPC
-    dynamic_value_parents: Optional[Set[str]] = None
+    dynamic_value_parents: Optional[set[str]] = None
     description: Optional[str] = None
     default_value: Optional[str] = None
     extra: Optional[str] = None
-    children: List["ParameterMeta"] = field(default_factory=list)
+    children: list["ParameterMeta"] = field(default_factory=list)
