@@ -1,6 +1,6 @@
 import functools
 import logging
-from typing import Any, Callable, Optional, Type, TypeVar, cast
+from typing import Any, Callable, Optional, TypeVar, cast
 
 from arcor2.exceptions import Arcor2Exception
 
@@ -8,9 +8,9 @@ F = TypeVar("F", bound=Callable[..., Any])
 
 
 def handle(
-    raise_type: Type[Arcor2Exception],
+    raise_type: type[Arcor2Exception],
     logger: logging.Logger,
-    except_type: Type[Arcor2Exception] = Arcor2Exception,
+    except_type: type[Arcor2Exception] = Arcor2Exception,
     message: Optional[str] = None,
 ) -> Callable[[F], F]:
     def _handle_exceptions(func: F) -> F:
